@@ -1,8 +1,8 @@
 __author__ = "Shyue Ping Ong, Anubhav Jain, Michael Kocher, " + \
              "Geoffroy Hautier, William Davidson Richard, Dan Gunter, " + \
              "Shreyas Cholia, Vincent L Chevrier, Rickard Armiento"
-__date__ = "Jun 28, 2012"
-__version__ = "2.1.0"
+__date__ = "Jul 27, 2012"
+__version__ = "2.1.2"
 
 """
 Useful aliases for commonly used objects and modules.
