@@ -19,7 +19,7 @@ import os
 import json
 import logging
 
-from pymatgen.util.io_utils import file_open_zip_aware
+from pymatgen.util.io_utils import zopen
 from pymatgen.serializers.json_coders import PMGJSONEncoder, PMGJSONDecoder
 
 from multiprocessing import Manager, Pool
@@ -29,9 +29,9 @@ logger = logging.getLogger("BorgQueen")
 
 class BorgQueen(object):
     """
-    The Borg Queen controls the drones to assimilate data in an entire directory
-    substructure. Uses multiprocessing to speed up things considerably. It also
-    contains convenience methods to save and load data between sessions.
+    The Borg Queen controls the drones to assimilate data in an entire 
+    directory tree. Uses multiprocessing to speed up things considerably. It
+    also contains convenience methods to save and load data between sessions.
     """
 
     def __init__(self, drone, rootpath=None, number_of_drones=1):
@@ -68,7 +68,8 @@ class BorgQueen(object):
         logger.info('Scanning for valid paths...')
         valid_paths = []
         for (parent, subdirs, files) in os.walk(rootpath):
-            valid_paths.extend(self._drone.get_valid_paths((parent, subdirs, files)))
+            valid_paths.extend(self._drone.get_valid_paths((parent, subdirs,
+                                                            files)))
         manager = Manager()
         data = manager.list()
         status = manager.dict()
@@ -76,7 +77,8 @@ class BorgQueen(object):
         status['total'] = len(valid_paths)
         logger.info('{} valid paths found.'.format(len(valid_paths)))
         p = Pool(self._num_drones)
-        p.map(_order_assimilation, ((path, self._drone, data, status) for path in valid_paths))
+        p.map(order_assimilation, ((path, self._drone, data, status) \
+                                    for path in valid_paths))
         for d in data:
             self._data.append(json.loads(d, cls=PMGJSONDecoder))
 
@@ -86,7 +88,8 @@ class BorgQueen(object):
         """
         valid_paths = []
         for (parent, subdirs, files) in os.walk(rootpath):
-            valid_paths.extend(self._drone.get_valid_paths((parent, subdirs, files)))
+            valid_paths.extend(self._drone.get_valid_paths((parent, subdirs,
+                                                            files)))
         data = []
         count = 0
         total = len(valid_paths)
@@ -94,7 +97,8 @@ class BorgQueen(object):
             newdata = self._drone.assimilate(path)
             self._data.append(newdata)
             count += 1
-            logger.info('{}/{} ({:.2f}%) done'.format(count, total, count / total * 100))
+            logger.info('{}/{} ({:.2f}%) done'.format(count, total,
+                                                      count / total * 100))
         for d in data:
             self._data.append(json.loads(d, cls=PMGJSONDecoder))
 
@@ -114,18 +118,18 @@ class BorgQueen(object):
                 filename ends with gz or bz2, the relevant gzip or bz2
                 compression will be applied.
         """
-        with file_open_zip_aware(filename, "w") as f:
+        with zopen(filename, "w") as f:
             json.dump(list(self._data), f, cls=PMGJSONEncoder)
 
     def load_data(self, filename):
         """
         Load assimilated data from a file
         """
-        with file_open_zip_aware(filename, "r") as f:
+        with zopen(filename, "r") as f:
             self._data = json.load(f, cls=PMGJSONDecoder)
 
 
-def _order_assimilation(args):
+def order_assimilation(args):
     """
     Internal helper method for BorgQueen to process assimilation
     """
@@ -136,6 +140,7 @@ def _order_assimilation(args):
     status['count'] += 1
     count = status['count']
     total = status['total']
-    logger.info('{}/{} ({:.2f}%) done'.format(count, total, count / total * 100))
+    logger.info('{}/{} ({:.2f}%) done'.format(count, total,
+                                              count / total * 100))
 
 
