@@ -42,6 +42,10 @@ class Lattice(MSONable):
                 ii) [[1, 0, 0],[0, 1, 0], [0, 0, 1]]
                 iii) [1, 0, 0 , 0, 1, 0, 0, 0, 1]
                 iv) (1, 0, 0, 0, 1, 0, 0, 0, 1)
+                
+                Each row should correspond to a lattice vector.
+                E.g., [[10,0,0], [20,10,0], [0,0,30]] specifies a lattice with
+                lattice vectors [10,0,0], [20,10,0] and [0,0,30].
         """
 
         self._matrix = np.array(matrix).reshape((3, 3))
@@ -49,6 +53,18 @@ class Lattice(MSONable):
         self._md2c = np.transpose(self._matrix)
         self._mc2d = npl.inv(np.transpose(self._matrix))
 
+        lengths = np.sum(self._matrix ** 2, axis=1) ** 0.5
+        angles = np.zeros((3), float)
+        for i in xrange(3):
+            j = (i + 1) % 3
+            k = (i + 2) % 3
+            angles[i] = np.dot(self._matrix[j], self._matrix[k]) / \
+                        (lengths[j] * lengths[k])
+        angles = np.arccos(angles) * 180. / pi
+        angles = np.around(angles, 9)
+        self._angles = tuple(angles)
+        self._lengths = tuple(lengths)
+
     @property
     def md2c(self):
         '''Matrix for converting direct to cartesian coordinates'''
@@ -204,7 +220,8 @@ class Lattice(MSONable):
         Returns:
             A Lattice with the specified lattice parameters.
         '''
-        return Lattice.from_parameters(abc[0], abc[1], abc[2], ang[0], ang[1], ang[2])
+        return Lattice.from_parameters(abc[0], abc[1], abc[2],
+                                       ang[0], ang[1], ang[2])
 
     @staticmethod
     def from_parameters(a, b, c, alpha, beta, gamma):
@@ -263,83 +280,70 @@ class Lattice(MSONable):
         """
         Returns the angles (alpha, beta, gamma) of the lattice.
         """
-        return self.lengths_and_angles[1]
+        return self._angles
 
     @property
     def a(self):
         """
         *a* lattice parameter.
         """
-        return self.abc[0]
+        return self._lengths[0]
 
     @property
     def b(self):
         """
         *b* lattice parameter.
         """
-        return self.abc[1]
+        return self._lengths[1]
 
     @property
     def c(self):
         """
         *c* lattice parameter.
         """
-        return self.abc[2]
+        return self._lengths[2]
 
     @property
     def abc(self):
         """
         Lengths of the lattice vectors, i.e. (a, b, c)
         """
-        return self.lengths_and_angles[0]
-
-    def _angle_between(self, x, y):
-        """ 
-        Internal method to calculate the angle between two vectors.
-        """
-        angle_between = 180.0 / np.pi * np.arccos(np.dot(x, y) / (np.linalg.norm(x) * np.linalg.norm(y)))
-        return angle_between
+        return self._lengths
 
     @property
     def alpha(self):
         """
         Angle alpha of lattice.
         """
-        return self._angle_between(self._matrix[1], self._matrix[2])
+        return self._angles[0]
 
     @property
     def beta(self):
         """
         Angle beta of lattice.
         """
-        return self._angle_between(self._matrix[0], self._matrix[2])
+        return self._angles[1]
 
     @property
     def gamma(self):
         """
         Angle gamma of lattice.
         """
-        return self._angle_between(self._matrix[0], self._matrix[1])
+        return self._angles[2]
 
     @property
     def volume(self):
         """
         Volume of the unit cell.
         """
-        return npl.det(self._matrix)
+        return abs(npl.det(self._matrix))
 
     @property
     def lengths_and_angles(self):
         '''
         Returns (lattice lengths, lattice angles).
         '''
-        prim = self._matrix
-        lengths = np.sum(prim ** 2, axis=1) ** 0.5
-        angles = np.zeros((3), float)
-        angles[0] = np.arccos(np.dot(prim[1], prim[2]) / (lengths[1] * lengths[2])) * 180. / pi
-        angles[1] = np.arccos(np.dot(prim[2], prim[0]) / (lengths[2] * lengths[0])) * 180. / pi
-        angles[2] = np.arccos(np.dot(prim[0], prim[1]) / (lengths[0] * lengths[1])) * 180. / pi
-        return lengths, np.around(angles, 9)
+        return self._lengths, self._angles
 
     @property
     def reciprocal_lattice(self):
@@ -404,18 +408,18 @@ class Lattice(MSONable):
         Args:
             lattice_type:
                 An alphabet indicating whether the lattice type, P - primitive,
-                R - rhombohedral, A - A-centered, B - B-centered, C - C-centered,
-                I - body-centered, F - F-centered.
+                R - rhombohedral, A - A-centered, B - B-centered,
+                C - C-centered, I - body-centered, F - F-centered.
         """
         if lattice_type == 'P':
             return Lattice(self._matrix)
         conv_to_prim = {
-            'R': np.array([[2 / 3, 1 / 3, 1 / 3], [-1 / 3, 1 / 3, 1 / 3], [-1 / 3, -2 / 3, 1 / 3]]),
-            'A': np.array([[1, 0, 0], [0, 1 / 2, 1 / 2], [0, -1 / 2, 1 / 2]]),
-            'B': np.array([[1 / 2, 0, 1 / 2], [0, 1, 0], [-1 / 2, 0, 1 / 2]]),
-            'C': np.array([[1 / 2, 1 / 2, 0], [-1 / 2, 1 / 2, 0], [0, 0, 1]]),
-            'I': np.array([[-1 / 2, 1 / 2, 1 / 2], [1 / 2, -1 / 2, 1 / 2], [1 / 2, 1 / 2, -1 / 2]]),
-            'F': np.array([[1 / 2, 1 / 2, 0], [0, 1 / 2, 1 / 2], [1 / 2, 0, 1 / 2]])
+            'R': np.array([[2, 1, 1], [-1, 1, 1], [-1, -2, 1]]) / 3,
+            'A': np.array([[2, 0, 0], [0, 1, 1], [0, -1, 1]]) / 2,
+            'B': np.array([[1, 0, 1], [0, 2, 0], [-1, 0, 1]]) / 2,
+            'C': np.array([[1, 1, 0], [-1, 1, 0], [0, 0, 2]]) / 2,
+            'I': np.array([[-1, 1, 1], [1, -1, 1], [1, 1, -1]]) / 2,
+            'F': np.array([[1, 1, 0], [0, 1, 1], [1, 0, 1]]) / 2
             }
         return Lattice(np.dot(conv_to_prim[lattice_type], self._matrix))
 
@@ -437,10 +441,12 @@ class Lattice(MSONable):
             take care of c
             """
             if np.dot(a, b) > 0:
-                diffvector = np.subtract(a, b)
+                diffvector = a - b
             else:
-                diffvector = np.add(a, b)
-            if np.linalg.norm(diffvector) < np.linalg.norm(a) or np.linalg.norm(diffvector) < np.linalg.norm(b):
+                diffvector = a + b
+            diffnorm = np.linalg.norm(diffvector)
+            if diffnorm < np.linalg.norm(a) or \
+               diffnorm < np.linalg.norm(b):
                 if np.linalg.norm(a) < np.linalg.norm(b):
                     b = diffvector
                 else:
@@ -450,11 +456,13 @@ class Lattice(MSONable):
             take care of b
             """
             if np.dot(a, c) > 0:
-                diffvector = np.subtract(a, c)
+                diffvector = a - c
             else:
-                diffvector = np.add(a, c)
-            if np.linalg.norm(diffvector) < np.linalg.norm(a) or np.linalg.norm(diffvector) < np.linalg.norm(c):
-                if(np.linalg.norm(a) < np.linalg.norm(c)):
+                diffvector = a + c
+            diffnorm = np.linalg.norm(diffvector)
+            if diffnorm < np.linalg.norm(a) or \
+               diffnorm < np.linalg.norm(c):
+                if np.linalg.norm(a) < np.linalg.norm(c):
                     c = diffvector
                 else:
                     a = diffvector
@@ -463,12 +471,13 @@ class Lattice(MSONable):
             take care of a
             """
             if np.dot(c, b) > 0:
-                diffvector = np.subtract(c, b)
+                diffvector = c - b
             else:
-                diffvector = np.add(c, b)
-            if(np.linalg.norm(diffvector) < np.linalg.norm(c)
-               or np.linalg.norm(diffvector) < np.linalg.norm(b)):
-                if(np.linalg.norm(c) < np.linalg.norm(b)):
+                diffvector = c + b
+            diffnorm = np.linalg.norm(diffvector)
+            if diffnorm < np.linalg.norm(c) or \
+               diffnorm < np.linalg.norm(b):
+                if np.linalg.norm(c) < np.linalg.norm(b):
                     b = diffvector
                 else:
                     c = diffvector
@@ -476,3 +485,80 @@ class Lattice(MSONable):
             if anychange == True:
                 break
         return Lattice([a, b, c])
+
+    def get_lll_reduced_lattice(self, delta=0.75):
+        """
+        Performs a Lenstra-Lenstra-Lovasz lattice basis reduction to obtain a 
+        c-reduced basis. This method returns a basis which is as "good" as
+        possible, with "good" defined by orthongonality of the lattice vectors.
+        
+        Args:
+            delta:
+                Reduction parameter. Default of 0.75 is usually fine.
+                
+        Returns:
+            Reduced lattice. 
+        """
+        #Transpose the lattice matrix first so that basis vectors are columns. 
+        #Makes life easier.
+        a = np.transpose(self._matrix.copy())
+
+        b = np.zeros((3, 3)) #Vectors after the Gram-Schmidt process
+        u = np.zeros((3, 3)) #Gram-Schmidt coeffieicnts
+        m = np.zeros(3) #These are the norm squared of each vec.
+
+        #We are going to use dot a lot. Let's make an alias.
+        dot = np.dot
+
+        b[:, 0] = a[:, 0]
+        m[0] = dot(b[:, 0], b[:, 0])
+        for i in xrange(1, 3):
+            u[i, 0:i] = dot(a[:, i].T, b[:, 0:i]) / m[0:i]
+            b[:, i] = a[:, i] - dot(b[:, 0:i], u[i, 0:i].T)
+            m[i] = dot(b[:, i], b[:, i])
+
+        k = 2
+
+        while k <= 3:
+            #Size reduction
+            for i in xrange(k - 1, 0, -1):
+                q = round(u[k - 1, i - 1])
+                if q != 0:
+                    #Reduce the k-th basis vector
+                    a[:, k - 1] = a[:, k - 1] - q * a[:, i - 1]
+                    uu = list(u[i - 1, 0:(i - 1)])
+                    uu.append(1)
+                    #Update the GS coefficients
+                    u[k - 1, 0:i] = u[k - 1, 0:i] - q * np.array(uu)
+
+            #Check the Lovasz condition
+            if dot(b[:, k - 1], b[:, k - 1]) >= \
+                (delta - abs(u[k - 1, k - 2]) ** 2) * \
+                             dot(b[:, (k - 2)], b[:, (k - 2)]):
+                #Increment k if the Lovasz condition holds
+                k += 1
+            else:
+                #If the Lovasz condition fails,
+                #swap the k-th and (k-1)-th basis vector
+                v = a[:, k - 1].copy()
+                a[:, k - 1] = a[:, k - 2].copy()
+                a[:, k - 2] = v
+                #Update the Gram-Schmidt coefficients
+                for s in xrange(k - 1, k + 1):
+                    u[s - 1, 0:(s - 1)] = dot(a[:, s - 1].T,
+                                              b[:, 0:(s - 1)]) / m[0:(s - 1)]
+                    b[:, s - 1] = a[:, s - 1] - dot(b[:, 0:(s - 1)],
+                                                    u[s - 1, 0:(s - 1)].T)
+                    m[s - 1] = dot(b[:, s - 1], b[:, s - 1])
+
+                if k > 2:
+                    k -= 1
+                else:
+                    # We have to do p/q, so do lstsq(q.T, p.T).T instead.
+                    p = dot(a[:, k:3].T, b[:, (k - 2):k])
+                    q = np.diag(m[(k - 2):k])
+                    result = np.linalg.lstsq(q.T, p.T)[0].T
+                    u[k:3, (k - 2):k] = result
+
+        return Lattice(a.T)
+
