@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
 """
-This module provides classes used to define a structure, such as Site,
-PeriodicSite, Structure, and Composition.
+This module provides classes used to define a non-periodic molecule and a 
+periodic structure.
 """
 
 from __future__ import division
@@ -27,546 +27,8 @@ from pymatgen.core.lattice import Lattice
 from pymatgen.core.periodic_table import Element, Specie, smart_element_or_specie
 from pymatgen.util.string_utils import formula_double_format
 from pymatgen.serializers.json_coders import MSONable
-
-
-class Site(collections.Mapping, collections.Hashable, MSONable):
-    '''
-    A generalized *non-periodic* site. Atoms and occupancies should be a dict
-    of element:occupancy or an element, in which case the occupancy default to 
-    1. Coords are given in standard cartesian coordinates.
-    '''
-
-    supported_properties = ('magmom', 'charge', 'coordination_no')
-
-    def __init__(self, atoms_n_occu, coords, properties=None):
-        """
-        Create a *non-periodic* site.
-        
-        Args:
-            atoms_n_occu: 
-                dict of elements or species and occupancies. Elements can be 
-                specified as symbols (Fe), atomic numbers (27), or actual 
-                Element objects.  Specie can be specified as Specie objects, 
-                or strings (Fe2+).
-            coords: 
-                Cartesian coordinates of site.
-            properties:
-                Properties associated with the site as a dict, e.g. 
-                {'magmom':5}. Defaults to None.
-        """
-
-        if isinstance(atoms_n_occu, dict):
-            self._species = {smart_element_or_specie(k): v \
-                             for k, v in atoms_n_occu.items()}
-            totaloccu = sum(self._species.values())
-            if totaloccu > 1:
-                raise ValueError("Species occupancies sum to more than 1!")
-            self._is_ordered = (totaloccu == 1 and len(self._species) == 1)
-        else:
-            self._species = {smart_element_or_specie(atoms_n_occu):1}
-            self._is_ordered = True
-        self._coords = coords
-        self._properties = properties if properties else {}
-        for k in self._properties.keys():
-            if k not in Site.supported_properties:
-                raise ValueError("{} is not a supported property".format(k))
-
-    @property
-    def properties(self):
-        """
-        Returns a view of properties as a dict.
-        """
-        return {k:v for k, v in self._properties.items()}
-
-    def __getattr__(self, a):
-        if a in self._properties:
-            return self._properties[a]
-        raise AttributeError(a)
-
-    def distance(self, other):
-        """
-        Get distance between two sites.
-        
-        Args:
-            other:
-                Other site.
-        """
-        return np.linalg.norm(other.coords - self.coords)
-
-    def distance_from_point(self, pt):
-        """
-        Returns distance between the site and a point in space.
-        
-        Args:
-            pt:
-                cartesian coordinates of point.
-        """
-        return np.linalg.norm(np.array(pt) - np.array(self._coords))
-
-    @property
-    def species_string(self):
-        """
-        String representation of species on the site.
-        """
-        if self._is_ordered:
-            return str(self._species.keys()[0])
-        else:
-            sorted_species = sorted(self._species.keys())
-            return ', '.join(["%s:%.3f" % (str(sp), self._species[sp]) \
-                              for sp in sorted_species])
-
-    @property
-    def species_and_occu(self):
-        """
-        The species at the site, i.e., a dict of element and occupancy
-        """
-        return self._species
-
-    @property
-    def specie(self):
-        """
-        .. deprecated:: 1.0
-            Use :func:`species_and_occu` instead.
-            
-        The Specie/Element at the site. Only works for ordered sites. Otherwise 
-        an AttributeError is raised. Use this property sparingly.  Robust
-        design should make use of the property species_and_occu instead.
-        
-        Raises:
-            AttributeError if Site is not ordered.
-        """
-        if not self._is_ordered:
-            raise AttributeError("specie property only works for ordered sites!")
-        return self._species.keys()[0]
-
-    @property
-    def coords(self):
-        """
-        A copy of the cartesian coordinates of the site as a numpy array.
-        """
-        return np.copy(self._coords)
-
-    @property
-    def is_ordered(self):
-        """
-        True if site is an ordered site, i.e., with a single species with 
-        occupancy 1.
-        """
-        return self._is_ordered
-
-    @property
-    def x(self):
-        """
-        Cartesian x coordinate
-        """
-        return self._coords[0]
-
-    @property
-    def y(self):
-        """
-        Cartesian y coordinate
-        """
-        return self._coords[1]
-
-    @property
-    def z(self):
-        """
-        Cartesian z coordinate
-        """
-        return self._coords[2]
-
-    def __getitem__(self, el):
-        '''
-        Get the occupancy for element
-        '''
-        return self._species[el]
-
-    def __eq__(self, other):
-        """
-        Site is equal to another site if the species and occupancies are the 
-        same, and the coordinates are the same to some tolerance.  numpy
-        function `allclose` is used to determine if coordinates are close.
-        """
-        if other == None:
-            return False
-        return self._species == other._species and \
-               np.allclose(self._coords, other._coords)
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    def __hash__(self):
-        '''
-        Minimally effective hash function that just distinguishes between Sites 
-        with different elements.
-        '''
-        hashcode = 0
-        for el in self._species.keys():
-            #Ignore elements with zero amounts.
-            if self[el] != 0:
-                hashcode += el.Z
-        return hashcode
-
-    def __contains__(self, el):
-        return el in self._species
-
-    def __len__(self):
-        return len(self._species)
-
-    def __iter__(self):
-        return self._species.__iter__()
-
-    def __repr__(self):
-        outs = []
-        outs.append("Non-periodic Site")
-        outs.append("xyz        : (%0.4f, %0.4f, %0.4f)" % tuple(self.coords))
-        for k, v in self._species.items():
-            outs.append("element    : %s" % k.symbol)
-            outs.append("occupation : %0.2f" % v)
-        return "\n".join(outs)
-
-    def __cmp__(self, other):
-        '''
-        Sets a default sort order for atomic species by electronegativity. Very
-        useful for getting correct formulas.  For example, FeO4PLi is 
-        automatically sorted in LiFePO4.
-        '''
-        def avg_electroneg(sps):
-            return sum([sp.X * occu for sp, occu in sps.items()])
-
-        if avg_electroneg(self._species) < avg_electroneg(other._species):
-            return -1
-        if avg_electroneg(self._species) > avg_electroneg(other._species):
-            return 1
-        return 0
-
-    def __str__(self):
-        return "%s %s" % (self._coords, ','.join(["%s %.4f" % (str(atom), occu)\
-                                     for atom, occu in self._species.items()]))
-
-    @property
-    def to_dict(self):
-        """
-        Json-serializable dict representation for Site.
-        """
-        species_list = []
-        for spec, occu in self._species.items():
-            d = spec.to_dict
-            d['occu'] = occu
-            species_list.append(d)
-        d = {'name': self.species_string, 'species': species_list,
-             'occu': occu, 'xyz':[float(c) for c in self._coords],
-             'properties': self._properties}
-        d['module'] = self.__class__.__module__
-        d['class'] = self.__class__.__name__
-        return d
-
-    @staticmethod
-    def from_dict(d):
-        """
-        Create Site from dict representation
-        """
-        atoms_n_occu = {}
-        for sp_occu in d['species']:
-            sp = Specie.from_dict(sp_occu) if 'oxidation_state' in sp_occu \
-                 else Element(sp_occu['element'])
-            atoms_n_occu[sp] = sp_occu['occu']
-        props = d.get('properties', None)
-        return Site(atoms_n_occu, d['xyz'], properties=props)
-
-
-class PeriodicSite(Site, MSONable):
-    """
-    Extension of generic Site object to periodic systems.
-    PeriodicSite includes a lattice system.
-    """
-
-    def __init__(self, atoms_n_occu, coords, lattice, to_unit_cell=False,
-                 coords_are_cartesian=False, properties=None):
-        """
-        Create a periodic site.
-        
-        Args:
-            atoms_n_occu:
-                dict of elements and occupancies
-            coords:
-                coordinates of site as fractional coordinates or cartesian 
-                coordinates.
-            lattice:
-                Lattice associated with the site
-            to_unit_cell:
-                translates fractional coordinate to the basic unit cell, i.e. 
-                all fractional coordinates satisfy 0 <= a < 1. Defaults to 
-                False.
-            coords_are_cartesian:
-                Set to True if you are providing cartesian coordinates. 
-                Defaults to False.
-            properties:
-                Properties associated with the PeriodicSite as a dict, e.g. 
-                {'magmom':5}. Defaults to None.
-        """
-        self._lattice = lattice
-        self._fcoords = self._lattice.get_fractional_coords(coords) \
-                        if coords_are_cartesian else coords
-
-        if to_unit_cell:
-            for i, fcoords in enumerate(self._fcoords):
-                self._fcoords[i] = fcoords - math.floor(fcoords)
-
-        c_coords = self._lattice.get_cartesian_coords(self._fcoords)
-        Site.__init__(self, atoms_n_occu, c_coords, properties)
-
-    @property
-    def lattice(self):
-        """
-        The lattice associated with the site.
-        """
-        return self._lattice
-
-    @property
-    def frac_coords(self):
-        """
-        The fractional coordinates of the site as a tuple.
-        """
-        return np.copy(self._fcoords)
-
-    @property
-    def a(self):
-        """
-        Fractional a coordinate
-        """
-        return self._fcoords[0]
-
-    @property
-    def b(self):
-        """
-        Fractional b coordinate
-        """
-        return self._fcoords[1]
-
-    @property
-    def c(self):
-        """
-        Fractional c coordinate
-        """
-        return self._fcoords[2]
-
-    @property
-    def to_unit_cell(self):
-        """
-        Copy of PeriodicSite translated to the unit cell.
-        """
-        fcoords = [i - math.floor(i) for i in self._fcoords]
-        return PeriodicSite(self._species, fcoords, self._lattice,
-                            properties=self._properties)
-
-    def is_periodic_image(self, other, tolerance=1e-8):
-        """
-        Returns True if sites are periodic images of each other.
-        """
-        if self.lattice != other.lattice:
-            return False
-        frac_diff = abs(np.array(self._fcoords) - np.array(other._fcoords)) % 1
-        frac_diff = [abs(a) < tolerance or abs(a) > 1 - tolerance \
-                     for a in frac_diff]
-        return  all(frac_diff)
-
-    def __eq__(self, other):
-        return self._species == other._species and \
-            self._lattice == other._lattice and \
-            np.allclose(self._coords, other._coords)
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    def distance_and_image_old(self, other, jimage=None):
-        """
-        .. deprecated:: 1.0
-            Use :func:`distance_and_image` instead. This code is kept for 
-            information reasons. A new version has been written which is more 
-            accurate, but at a higher computational cost.
-        
-        Gets distance between two sites assuming periodic boundary conditions.
-        If the index jimage of two sites atom j is not specified it selects the 
-        j image nearest to the i atom and returns the distance and jimage
-        indices in terms of lattice vector translations. If the index jimage of
-        atom j is specified it returns the distance between the i atom and the
-        specified jimage atom, the given jimage is also returned.
-        
-        Args:
-            other:
-                other site to get distance from.
-            jimage:
-                specific periodic image in terms of lattice translations, 
-                e.g., [1,0,0] implies to take periodic image that is one 
-                a-lattice vector away. If jimage == None, the image that is 
-                nearest to the site is found.
-        
-        Returns:
-            (distance, jimage):
-                distance and periodic lattice translations of the other site 
-                for which the distance applies.
-        
-        .. note::
-            Assumes the primitive cell vectors are sufficiently not skewed such 
-            that the condition \|a\|cos(ab_angle) < \|b\| for all possible cell
-            vector pairs. ** this method does not check this condition **
-        """
-        if jimage == None:
-            #Old algorithm
-            jimage = -np.array(np.around(other._fcoords - self._fcoords), int)
-        return np.linalg.norm(self.lattice.get_cartesian_coords(jimage + \
-                                    other._fcoords - self._fcoords)), jimage
-
-    def distance_and_image_from_frac_coords(self, fcoords, jimage=None):
-        """
-        Gets distance between site and a fractional coordinate assuming 
-        periodic boundary conditions. If the index jimage of two sites atom j 
-        is not specified it selects the j image nearest to the i atom and
-        returns the distance and jimage indices in terms of lattice vector 
-        translations. If the index jimage of atom j is specified it returns the
-        distance between the i atom and the specified jimage atom, the given 
-        jimage is also returned.
-        
-        Args:
-            fcoords:
-                fcoords to get distance from.
-            jimage:
-                specific periodic image in terms of lattice translations, 
-                e.g., [1,0,0] implies to take periodic image that is one 
-                a-lattice vector away. If jimage == None, the image that is
-                nearest to the site is found.
-        
-        Returns:
-            (distance, jimage):
-                distance and periodic lattice translations of the other site
-                for which the distance applies.
-        """
-        if jimage == None:
-            #The following code is heavily vectorized to maximize speed.
-
-            #Get the image adjustment necessary to bring coords to unit_cell.
-            adj1 = np.array([-math.floor(i) for i in self._fcoords])
-            adj2 = np.array([-math.floor(i) for i in fcoords])
-
-            #Shift coords to unitcell
-            coord1 = self._fcoords + adj1
-            coord2 = fcoords + adj2
-
-            #Generate set of images required for testing.
-            test_set = [[-1, 0] if coord1[i] < coord2[i] else [0, 1] \
-                        for i in range(3)]
-            images = [image for image in itertools.product(*test_set)]
-
-            #Create vectorized cartesian coords tiling for computing distances.
-            vec = np.tile(coord2, (8, 1)) - np.tile(coord1, (8, 1)) + images
-            vec = self._lattice.get_cartesian_coords(vec)
-
-            #Compute distances manually.
-            dist = np.sqrt(np.sum(vec ** 2, 1)).tolist()
-
-            #Return the minimum distance and the adjusted image corresponding
-            #to the min distance.
-            mindist = min(dist)
-            ind = dist.index(mindist)
-            return mindist, adj2 - adj1 + images[ind]
-
-        return np.linalg.norm(self.lattice.get_cartesian_coords(jimage + \
-                                            fcoords - self._fcoords)), jimage
-
-    def distance_and_image(self, other, jimage=None):
-        """
-        Gets distance and instance between two sites assuming periodic boundary 
-        conditions. If the index jimage of two sites atom j is not specified it
-        selects the j image nearest to the i atom and returns the distance and 
-        jimage indices in terms of lattice vector translations. If the index
-        jimage of atom j is specified it returns the distance between the ith
-        atom and the specified jimage atom, the given jimage is also returned.
-        
-        Args:
-            other:
-                other site to get distance from.
-            jimage:
-                specific periodic image in terms of lattice translations, 
-                e.g., [1,0,0] implies to take periodic image that is one 
-                a-lattice vector away. If jimage == None, the image that is 
-                nearest to the site is found.
-        
-        Returns:
-            (distance, jimage):
-                distance and periodic lattice translations of the other site 
-                for which the distance applies.
-        """
-        return self.distance_and_image_from_frac_coords(other._fcoords, jimage)
-
-    def distance(self, other, jimage=None):
-        """
-        Get distance between two sites assuming periodic boundary conditions.
-        
-        Args:
-            other:
-                other site to get distance from.
-            jimage:   
-                specific periodic image in terms of lattice translations, 
-                e.g., [1,0,0] implies to take periodic image that is one
-                a-lattice vector away. If jimage == None, the image that is
-                nearest to the site is found.
-        
-        Returns:
-            distance:
-                distance between the two sites
-        
-        """
-        return self.distance_and_image(other, jimage)[0]
-
-    def __repr__(self):
-        outs = []
-        outs.append("Periodic Site")
-        outs.append("abc : (%0.4f, %0.4f, %0.4f)" % tuple(self._fcoords))
-        for k, v in self._species.items():
-            outs.append("element    : %s" % k.symbol)
-            outs.append("occupation : %0.2f" % v)
-        return "\n".join(outs)
-
-    @property
-    def to_dict(self):
-        """
-        Json-serializable dict representation of PeriodicSite.
-        """
-        species_list = []
-        for spec, occu in self._species.items():
-            d = spec.to_dict
-            d['occu'] = occu
-            species_list.append(d)
-        d = {'label': self.species_string, 'species': species_list,
-             'occu': occu, 'xyz':[float(c) for c in self._coords],
-             'abc':[float(c) for c in self._fcoords],
-             'lattice': self._lattice.to_dict,
-             'properties': self._properties}
-        d['module'] = self.__class__.__module__
-        d['class'] = self.__class__.__name__
-        return d
-
-    @staticmethod
-    def from_dict(d, lattice=None):
-        """
-        Create PeriodicSite from dict representation.
-        
-        Args:
-            d:
-                dict representation of PeriodicSite
-            lattice:
-                Optional lattice to override lattice specified in d. Useful for
-                ensuring all sites in a structure share the same lattice.
-        """
-        atoms_n_occu = {}
-        for sp_occu in d['species']:
-            sp = Specie.from_dict(sp_occu) if 'oxidation_state' in sp_occu \
-                 else Element(sp_occu['element'])
-            atoms_n_occu[sp] = sp_occu['occu']
-        props = d.get('properties', None)
-        lattice = lattice if lattice else Lattice.from_dict(d['lattice'])
-        return PeriodicSite(atoms_n_occu, d['abc'], lattice, properties=props)
+from pymatgen.core.sites import Site, PeriodicSite
+from pymatgen.core.bonds import CovalentBond
 
 
 class SiteCollection(collections.Sequence, collections.Hashable):
@@ -774,7 +236,7 @@ class Structure(SiteCollection, MSONable):
     structure is equivalent to going through the sites in sequence.
     """
 
-    def __init__(self, lattice, atomicspecies, coords, validate_proximity=False,
+    def __init__(self, lattice, species, coords, validate_proximity=False,
                  to_unit_cell=False, coords_are_cartesian=False,
                  site_properties=None):
         """
@@ -782,12 +244,22 @@ class Structure(SiteCollection, MSONable):
         
         Args:
             lattice:
-                pymatgen.core.lattice Lattice object signify the lattice.
-            atomicspecies:
-                list of atomic species. Possible kinds of input include a list 
-                of dict of elements/species and occupancies, a List of 
-                elements/specie specified as actual Element/Specie, Strings 
-                ("Fe", "Fe2+") or atomic numbers (1,56).
+                The lattice, either as a pymatgen.core.lattice.Lattice or simply
+                as any 2D array. Each row should correspond to a lattice vector.
+                E.g., [[10,0,0], [20,10,0], [0,0,30]] specifies a lattice with
+                lattice vectors [10,0,0], [20,10,0] and [0,0,30].
+            species:
+                List of species on each site. Can take in flexible input,
+                including:
+                
+                i.  A sequence of element / specie specified either as string
+                    symbols, e.g. ["Li", "Fe2+", "P", ...] or atomic numbers,
+                    e.g., (3, 56, ...) or actual Element or Specie objects.
+                
+                ii. List of dict of elements/species and occupancies, e.g.,
+                    [{'Fe' : 0.5, 'Mn':0.5}, ...]. This allows the setup of
+                    disordered structures.
+            
             fractional_coords:
                 list of fractional coordinates of each species.
             validate_proximity:
@@ -802,7 +274,7 @@ class Structure(SiteCollection, MSONable):
                 length as the atomic species and fractional_coords.
                 Defaults to None for no properties.
         """
-        if len(atomicspecies) != len(coords):
+        if len(species) != len(coords):
             raise StructureError(("The list of atomic species must be of the",
                                   "same length as the list of fractional",
                                   " coordinates."))
@@ -813,11 +285,11 @@ class Structure(SiteCollection, MSONable):
             self._lattice = Lattice(lattice)
 
         self._sites = []
-        for i in xrange(len(atomicspecies)):
+        for i in xrange(len(species)):
             prop = None
             if site_properties:
                 prop = {k:v[i] for k, v in site_properties.items()}
-            self._sites.append(PeriodicSite(atomicspecies[i], coords[i],
+            self._sites.append(PeriodicSite(species[i], coords[i],
                                             self._lattice, to_unit_cell,
                                             coords_are_cartesian,
                                             properties=prop))
@@ -828,8 +300,6 @@ class Structure(SiteCollection, MSONable):
                     raise StructureError(("Structure contains sites that are ",
                                           "less than 0.01 Angstrom apart!"))
 
-        self._sites = tuple(self._sites)
-
     @staticmethod
     def from_sites(sites):
         """
@@ -858,7 +328,7 @@ class Structure(SiteCollection, MSONable):
         """
         Returns the sites in the Structure. 
         """
-        return self._sites
+        return tuple(self._sites)
 
     @property
     def lattice(self):
@@ -1042,7 +512,7 @@ class Structure(SiteCollection, MSONable):
             sites contribute to the ewald sum.
         """
 
-        #use same algorithm as getAtomsInSphere to determine supercell but
+        #use same algorithm as get_sites_in_sphere to determine supercell but
         #loop over all atoms in crystal
         recp_len = self.lattice.reciprocal_lattice.abc
         sr = r + 0.15
@@ -1122,7 +592,7 @@ class Structure(SiteCollection, MSONable):
         sites = sorted(self.sites)
         return Structure.from_sites(sites)
 
-    def copy(self, site_properties=None):
+    def copy(self, site_properties=None, sanitize=False):
         """
         Convenience method to get a copy of the structure, with options to add
         site properties.
@@ -1131,16 +601,41 @@ class Structure(SiteCollection, MSONable):
             site_properties:
                 Properties to add or override. The properties are specified in
                 the same way as the constructor, i.e., as a dict of the form
-                {property: [values]}.
+                {property: [values]}. The properties should be in the order of
+                the *original* structure if you are performing sanitization.
+            sanitize:
+                If True, this method will return a sanitized structure.
+                Sanitization performs a few things: (i) The sites are sorted
+                by electronegativity, (ii) a LLL lattice reduction is carried
+                out to obtain a relatively orthogonalized cell, (iii) all
+                fractional coords for sites are mapped into the unit cell.
+                
+        Returns:
+            A copy of the Structure, with optionally new site_properties and
+            optionally sanitized.
         """
         sites = self.sites
         props = self.site_properties
         if site_properties:
             props.update(site_properties)
-        return Structure(self._lattice,
-                         [site.species_and_occu for site in sites],
-                         [site.frac_coords for site in sites],
-                         site_properties=props)
+        if not sanitize:
+            return Structure(self._lattice,
+                             [site.species_and_occu for site in sites],
+                             [site.frac_coords for site in sites],
+                             site_properties=props)
+        else:
+            reduced_latt = self._lattice.get_lll_reduced_lattice()
+            new_sites = []
+            for i, site in enumerate(sites):
+                frac_coords = reduced_latt.get_fractional_coords(site.coords)
+                site_props = {}
+                for p in props:
+                    site_props[p] = props[p][i]
+                new_sites.append(PeriodicSite(site.species_and_occu, frac_coords,
+                                         reduced_latt, to_unit_cell=True,
+                                         properties=site_props))
+            new_sites = sorted(new_sites)
+            return Structure.from_sites(new_sites)
 
     def interpolate(self, end_structure, nimages=10):
         '''
@@ -1249,13 +744,13 @@ class Molecule(SiteCollection, MSONable):
     it can be used like any Python sequence. Iterating through a molecule is
     equivalent to going through the sites in sequence.
     """
-    def __init__(self, atomicspecies, coords, validate_proximity=False,
+    def __init__(self, species, coords, validate_proximity=False,
                  site_properties=None):
         """
         Creates a Molecule.
         
         Args:
-            atomicspecies:
+            species:
                 list of atomic species. Possible kinds of input include a list
                 of dict of elements/species and occupancies, a List of 
                 elements/specie specified as actual Element/Specie, Strings 
@@ -1271,17 +766,17 @@ class Molecule(SiteCollection, MSONable):
                 length as the atomic species and fractional_coords.
                 Defaults to None for no properties.
         """
-        if len(atomicspecies) != len(coords):
+        if len(species) != len(coords):
             raise StructureError(("The list of atomic species must be of the",
                                   " same length as the list of fractional ",
                                   "coordinates."))
 
         sites = []
-        for i in xrange(len(atomicspecies)):
+        for i in xrange(len(species)):
             prop = None
             if site_properties:
                 prop = {k:v[i] for k, v in site_properties.items()}
-            sites.append(Site(atomicspecies[i], coords[i], properties=prop))
+            sites.append(Site(species[i], coords[i], properties=prop))
         if validate_proximity:
             for (s1, s2) in itertools.combinations(sites, 2):
                 if s1.distance(s2) < Structure.DISTANCE_TOLERANCE:
@@ -1296,6 +791,58 @@ class Molecule(SiteCollection, MSONable):
         """
         return self._sites
 
+    @staticmethod
+    def from_sites(sites):
+        """
+        Convenience static constructor to make a Molecule from a list of sites.
+        
+        Args:
+            sites:
+                Sequence of Sites.
+        """
+        props = collections.defaultdict(list)
+        for site in sites:
+            for k, v in site.properties.items():
+                props[k].append(v)
+        return Molecule([site.species_and_occu for site in sites],
+                        [site.coords for site in sites],
+                        site_properties=props)
+
+    def break_bond(self, ind1, ind2):
+        """
+        Returns two molecules based on breaking the bond between atoms at index
+        ind1 and ind2.
+        """
+        sites = self._sites
+        clusters = [[sites[ind1]], [sites[ind2]]]
+
+        sites = [sites[i] for i in xrange(len(sites)) if i not in (ind1, ind2)]
+
+        def belongs_to_cluster(site, cluster):
+            for test_site in cluster:
+                if CovalentBond.is_bonded(site, test_site):
+                    return True
+            return False
+
+        while len(sites) > 0:
+            unmatched = []
+            for site in sites:
+                found = False
+                for cluster in clusters:
+                    if belongs_to_cluster(site, cluster):
+                        cluster.append(site)
+                        found = True
+                        break
+                if not found:
+                    unmatched.append(site)
+
+            if len(unmatched) == len(sites):
+                raise ValueError("Not all sites are matched!")
+                break
+            sites = unmatched
+
+        return (Molecule.from_sites(cluster) for cluster in clusters)
+
     def __repr__(self):
         outs = []
         outs.append("Molecule Summary")
@@ -1691,8 +1238,8 @@ class Composition (collections.Mapping, collections.Hashable, MSONable):
         num_el = len(syms)
         contains_polyanion = False
         if num_el >= 3:
-            contains_polyanion = (Element(syms[num_el - 1]).X - \
-                                  Element(syms[num_el - 2]).X < 1.65)
+            contains_polyanion = (smart_element_or_specie(syms[num_el - 1]).X - \
+                                  smart_element_or_specie(syms[num_el - 2]).X < 1.65)
 
         factor = reduce(gcd, self._elmap.values())
         reduced_form = ''
@@ -1773,7 +1320,7 @@ class Composition (collections.Mapping, collections.Hashable, MSONable):
         '''
         Args:
             el:
-                Element
+                Element or Specie
         
         Returns:
             Atomic fraction for element el in Composition
@@ -1784,7 +1331,7 @@ class Composition (collections.Mapping, collections.Hashable, MSONable):
         '''
         Args:
             el:
-                Element
+                Element or Specie
         
         Returns:
             Weight fraction for element el in Composition
@@ -2092,6 +1639,7 @@ class Composition (collections.Mapping, collections.Hashable, MSONable):
                     for match in Composition._recursive_compositions_from_fuzzy_formula(m_form2, m_dict2, m_points2, factor):
                         yield match
 
+
 if __name__ == "__main__":
     import doctest
     doctest.testmod()
