@@ -20,7 +20,8 @@ import itertools
 import numpy as np
 from pymatgen.core.periodic_table import Specie, Element
 from pymatgen.core.lattice import Lattice
-from pymatgen.core.structure import Structure, PeriodicSite, Site, Molecule
+from pymatgen.core.sites import PeriodicSite, Site
+from pymatgen.core.structure import Structure, Molecule
 
 
 class StructureModifier(object):
@@ -192,7 +193,8 @@ class StructureEditor(StructureModifier):
             new_site = PeriodicSite(species, coords, self._lattice,
                                     properties=properties)
         else:
-            new_site = PeriodicSite(species, self._lattice.get_fractional_coords(coords),
+            new_site = PeriodicSite(species,
+                                    self._lattice.get_fractional_coords(coords),
                                     self._lattice, properties=properties)
 
         if validate_proximity:
@@ -347,7 +349,7 @@ class SupercellMaker(StructureModifier):
         new_lattice = Lattice(np.dot(scale_matrix, old_lattice.matrix))
         new_sites = []
         def range_vec(i):
-            return range(max(scale_matrix[:][:, i]) - min(scale_matrix[:][:, i]))
+            return range(max(scale_matrix[:][:, i]) - min(scale_matrix[:][:, i]) + 1)
         for site in structure.sites:
             for (i, j, k) in itertools.product(range_vec(0), range_vec(1), range_vec(2)):
                 fcoords = site.frac_coords
