@@ -18,22 +18,24 @@ import os
 import ConfigParser
 from collections import defaultdict
 
-from pymatgen.core.periodic_table import Element
+from pymatgen.core.structure import Composition
 from pymatgen.entries.post_processors_abc import EntryPostProcessor
-from pymatgen.io.vaspio_set import MaterialsProjectVaspInputSet, MITVaspInputSet
+from pymatgen.io.vaspio_set import VaspInputSet
 
-class MaterialsProjectCompatibility(EntryPostProcessor):
+
+class Compatibility(EntryPostProcessor):
     """
     This class implements the GGA/GGA+U mixing scheme, which allows mixing of
-    entries. Note that this should only be used for VASP calculations using the
-    MaterialsProject parameters (see pymatgen.io.vaspio_set 
-    MaterialsProjectVaspInputSet). Using this compatibility scheme on runs with
-    different parameters is not valid.
+    entries. This is a base class from which other specific compatibility
+    schemes are implemented.
     """
 
-    def __init__(self, compat_type="Advanced"):
+    def __init__(self, input_set_name, compat_type):
         """
-        Arguments:
+        Args:
+            input_set_name:
+                The name of the input set to use. Can be either MaterialsProject
+                or MITMatgen.
             compat_type:
                 Two options, GGA or Advanced.  GGA means all GGA+U entries are 
                 excluded.  Advanced means mixing scheme is implemented to make 
@@ -44,47 +46,50 @@ class MaterialsProjectCompatibility(EntryPostProcessor):
                 under the scheme.
         """
         self.compat_type = compat_type
+        self.input_set_name = input_set_name
+        self.input_set = VaspInputSet(input_set_name)
+
         module_dir = os.path.dirname(os.path.abspath(__file__))
         self._config = ConfigParser.SafeConfigParser()
         self._config.optionxform = str
         self._config.readfp(open(os.path.join(module_dir, "Compatibility.cfg")))
-        u_corrections = dict(self._config.items('AdvancedUCorrections'))
-        u_corrections_sulfides = dict(self._config.items('AdvancedUCorrectionsSulfides'))
-        cpd_energies = dict(self._config.items('AdvancedCompoundEnergies'))
+        u_corrections = {}
+        for el in self.input_set.incar_settings['LDAUU'].keys():
+            name = '{}{}UCorrections{}'.format(input_set_name, compat_type, el)
+            if name in self._config.sections():
+                corr = dict(self._config.items(name))
+                u_corrections[el] = {k: float(v) for k, v in corr.items()}
 
-        self._u_corrections = dict()
-        for key, val in u_corrections.items():
-            self._u_corrections[Element(key)] = float(val)
-        self._u_corrections_sulfides = dict()
-        for key, val in u_corrections_sulfides.items():
-            self._u_corrections_sulfides[Element(key)] = float(val)
-        self._cpd_energies = dict()
-        for key, val in cpd_energies.items():
-            self._cpd_energies[key] = float(val)
+        cpd_energies = dict(self._config.items('{}{}CompoundEnergies'.format(input_set_name, compat_type)))
 
-        input_set = MaterialsProjectVaspInputSet()
-        self._valid_potcars = set(input_set.potcar_settings.values())
-        self._oxide_u = {Element(k): v for k, v in input_set.incar_settings["LDAUU"].items()}
+        self._u_corrections = u_corrections
+        self._cpd_energies = {k: float(v) for k, v in cpd_energies.items()}
+
+        self._valid_potcars = set(self.input_set.potcar_settings.values())
+        self._u_settings = self.input_set.incar_settings['LDAUU']
 
         if compat_type == "GGA":
-            self._u_corrections = dict()
-            self._u_corrections_sulfides = dict()
-            self._oxide_u = defaultdict(int)
+            self._u_corrections = {}
+            self._u_settings = {}
+
+    def requires_hubbard(self, comp):
+        comp = Composition(comp)
+        elements = sorted([el for el in comp.elements if comp[el] > 0],
+                              key=lambda el: el.X)
+        most_electroneg = elements[-1].symbol
+
+        usettings = self._u_settings.get(most_electroneg, {})
+
+        return any([usettings.get(el.symbol, 0) for el in comp.elements])
 
-    def has_u_element_oxides(self, comp):
-        if Element("O") not in comp:
-            return False
-        for el in comp.elements:
-            if el in self._oxide_u:
-                return True
-        return False
 
     def process_entry(self, entry):
         """
         Process a single entry with the chosen Compatibility scheme.
         
         Args:
-            entry - An ComputedEntry object.
+            entry:
+                A ComputedEntry object.
         
         Returns:
             An adjusted entry if entry is compatible, otherwise None is returned.
@@ -94,8 +99,8 @@ class MaterialsProjectCompatibility(EntryPostProcessor):
 
         ucorr = self._u_corrections
         cpdenergies = self._cpd_energies
-        u_settings = entry.parameters['hubbards']
-        u_settings = defaultdict(int) if u_settings == None else u_settings
+        calc_u = entry.parameters['hubbards']
+        calc_u = defaultdict(int) if calc_u == None else calc_u
         comp = entry.composition
         #Check that POTCARs are valid
         rform = comp.reduced_formula
@@ -104,26 +109,28 @@ class MaterialsProjectCompatibility(EntryPostProcessor):
             if not self._valid_potcars.issuperset(psp_settings):
                 return None
 
-        if comp.is_element:
-            #correct all elements that are wrong, e.g. O2 molecule
-            if rform in cpdenergies:
-                entry.structureid = -comp.keys()[0].Z
-                entry.correction = cpdenergies[rform] * comp.num_atoms - entry.uncorrected_energy
-            return entry
-        elif self.has_u_element_oxides(comp):
-            correction = 0
-            for el in comp.elements:
-                if el in ucorr:
-                    if el.symbol in u_settings and u_settings[el.symbol] == self._oxide_u[el]:
-                        correction += float(ucorr[el]) * comp[el]
-                    else:
-                        return None
-            entry.correction = correction
-            return entry
+        #correct all compounds that are wrong, e.g. O2 molecule
+        if rform in cpdenergies:
+            entry.structureid = -comp.keys()[0].Z
+            entry.correction = cpdenergies[rform] * comp.num_atoms - entry.uncorrected_energy
         else:
-            if entry.parameters['is_hubbard'] and entry.parameters['hubbards']:
-                return None
+            elements = sorted([el for el in comp.elements if comp[el] > 0],
+                              key=lambda el: el.X)
+            most_electroneg = elements[-1].symbol
+            correction = 0
 
+            ucorr = self._u_corrections.get(most_electroneg, {})
+            usettings = self._u_settings.get(most_electroneg, {})
+
+            for el in comp.elements:
+                sym = el.symbol
+                #Check for bad U values
+                if calc_u.get(sym, 0) != usettings.get(sym, 0):
+                    return None
+                if sym in ucorr:
+                    correction += float(ucorr[sym]) * comp[el]
+
+            entry.correction = correction
         return entry
 
     def process_entries(self, entries):
@@ -149,7 +156,31 @@ class MaterialsProjectCompatibility(EntryPostProcessor):
         return self._cpd_energies.keys()
 
     def __str__(self):
-        return self.compat_type + " Compatibility corrects element states and mixes GGA/GGA+U calcs"
+        return "{} {} Compatibility".format(self.input_set_name, self.compat_type)
+
+
+class MaterialsProjectCompatibility(Compatibility):
+    """
+    This class implements the GGA/GGA+U mixing scheme, which allows mixing of
+    entries. Note that this should only be used for VASP calculations using the
+    MaterialsProject parameters (see pymatgen.io.vaspio_set 
+    MaterialsProjectVaspInputSet). Using this compatibility scheme on runs with
+    different parameters is not valid.
+    """
+
+    def __init__(self, compat_type="Advanced"):
+        """
+        Arguments:
+            compat_type:
+                Two options, GGA or Advanced.  GGA means all GGA+U entries are 
+                excluded.  Advanced means mixing scheme is implemented to make 
+                entries compatible with each other, but entries which are 
+                supposed to be done in GGA+U will have the equivalent GGA entries 
+                excluded. For example, Fe oxides should have a U value under the 
+                Advanced scheme. A GGA Fe oxide run will therefore be excluded 
+                under the scheme.
+        """
+        Compatibility.__init__(self, "MaterialsProject", compat_type)
 
 
 
@@ -173,38 +204,4 @@ class MITCompatibility(MaterialsProjectCompatibility):
                 Advanced scheme. A GGA Fe oxide run will therefore be excluded 
                 under the scheme.
         """
-        self.compat_type = compat_type
-        module_dir = os.path.dirname(os.path.abspath(__file__))
-        self._config = ConfigParser.SafeConfigParser()
-        self._config.optionxform = str
-        self._config.readfp(open(os.path.join(module_dir, "MITCompatibility.cfg")))
-        u_corrections = dict(self._config.items('AdvancedUCorrections'))
-        u_corrections_sulfides = dict(self._config.items('AdvancedUCorrectionsSulfides'))
-        cpd_energies = dict(self._config.items('AdvancedCompoundEnergies'))
-
-        self._u_corrections = dict()
-        for key, val in u_corrections.items():
-            self._u_corrections[Element(key)] = float(val)
-        self._u_corrections_sulfides = dict()
-        for key, val in u_corrections_sulfides.items():
-            self._u_corrections_sulfides[Element(key)] = float(val)
-        self._cpd_energies = dict()
-        for key, val in cpd_energies.items():
-            self._cpd_energies[key] = float(val)
-
-        input_set = MITVaspInputSet()
-        self._valid_potcars = set(input_set.potcar_settings.values())
-        self._oxide_u = {Element(k): v for k, v in input_set.incar_settings["LDAUU"].items()}
-
-        if compat_type == "GGA":
-            self._u_corrections = dict()
-            self._u_corrections_sulfides = dict()
-            self._oxide_u = defaultdict(int)
-
-    def has_u_element_oxides(self, comp):
-        if Element("O") not in comp and Element("F") not in comp:
-            return False
-        for el in comp.elements:
-            if el in self._oxide_u:
-                return True
-        return False
+        Compatibility.__init__(self, "MITMatgen", compat_type)
