@@ -25,6 +25,12 @@ from pymatgen.serializers.json_coders import MSONable, PMGJSONDecoder
 class PDEntry(MSONable):
     """
     An object encompassing all relevant data for phase diagrams.
+    
+    .. attribute:: name
+        
+        A name for the entry. This is the string shown in the phase diagrams.
+        By default, this is the reduced formula for the composition, but can be
+        set to some other string for display purposes. 
     """
 
     def __init__(self, composition, energy, name=None):
@@ -39,8 +45,8 @@ class PDEntry(MSONable):
                 chemical formula.
         """
         self._energy = energy
-        self._composition = composition
-        self._name = name if name else composition.reduced_formula
+        self._composition = Composition(composition)
+        self.name = name if name else self._composition.reduced_formula
 
     @property
     def energy(self):
@@ -56,13 +62,6 @@ class PDEntry(MSONable):
         """
         return self.energy / self.composition.num_atoms
 
-    @property
-    def name(self):
-        """
-        Returns the name for an entry.
-        """
-        return self._name
-
     @property
     def composition(self):
         """
@@ -78,10 +77,11 @@ class PDEntry(MSONable):
         return self._composition.is_element
 
     def __repr__(self):
-        return "PDEntry with composition %s, energy = %.4f" % (self.composition.__str__(), self.energy)
+        return "PDEntry : {} with energy = {:.4f}".format(self.composition,
+                                                          self.energy)
 
     def __str__(self):
-        return "PDEntry : " + self.composition.__str__()
+        return self.__repr__()
 
     @property
     def to_dict(self):
@@ -90,7 +90,7 @@ class PDEntry(MSONable):
         d['class'] = self.__class__.__name__
         d['composition'] = self._composition.to_dict
         d['energy'] = self._energy
-        d['name'] = self._name
+        d['name'] = self.name
         return d
 
     @staticmethod
@@ -113,7 +113,7 @@ class GrandPotPDEntry(PDEntry):
                 Chemical potential specification as {Element: float}.
             name:
                 Optional parameter to name the entry. Defaults to the reduced
-                chemical formula.
+                chemical formula of the original entry.
         """
         comp = entry.composition
         self._original_entry = entry
@@ -126,6 +126,7 @@ class GrandPotPDEntry(PDEntry):
                 new_comp_map[el] = comp[el]
         newcomposition = Composition(new_comp_map)
         super(GrandPotPDEntry, self).__init__(newcomposition, grandpot, entry.name)
+        self.name = name if name else entry.name
 
     @property
     def original_entry(self):
@@ -134,13 +135,6 @@ class GrandPotPDEntry(PDEntry):
         '''
         return self._original_entry
 
-    @property
-    def name(self):
-        """
-        Returns the name for an entry.
-        """
-        return self._original_comp.reduced_formula
-
     @property
     def is_element(self):
         """
@@ -149,10 +143,12 @@ class GrandPotPDEntry(PDEntry):
         return self._original_comp.is_element
 
     def __repr__(self):
-        return "GrandPotPDEntry with original composition %s, energy = %.4f, %s" % (str(self.original_entry.composition), self.original_entry.energy, ' '.join(["mu_%s = %.4f" % (el, mu) for el, mu in self.chempots.items()]))
+        return "GrandPotPDEntry with original composition {}, energy = {:.4f}, {}".format(self.original_entry.composition,
+                self.original_entry.energy,
+                ' '.join(["mu_%s = %.4f" % (el, mu) for el, mu in self.chempots.items()]))
 
     def __str__(self):
-        return "GrandPotPDEntry with original composition " + str(self.original_entry.composition) + " and " + ' '.join(["mu_%s = %.4f" % (el, mu) for el, mu in self.chempots.items()])
+        return self.__repr__()
 
     @property
     def to_dict(self):
@@ -161,7 +157,7 @@ class GrandPotPDEntry(PDEntry):
         d['class'] = self.__class__.__name__
         d['entry'] = self._original_entry.to_dict
         d['chempots'] = {el.symbol: u for el, u in self.chempots.items()}
-        d['name'] = self._name
+        d['name'] = self.name
         return d
 
     @staticmethod
@@ -170,6 +166,14 @@ class GrandPotPDEntry(PDEntry):
         entry = PMGJSONDecoder().process_decoded(d['entry'])
         return GrandPotPDEntry(entry, chempots, d['name'])
 
+    def __getattr__(self, a):
+        """
+        Delegate attribute to original entry if available.
+        """
+        if hasattr(self._original_entry, a):
+            return getattr(self._original_entry, a)
+        raise AttributeError(a)
+
 
 class PDEntryIO(object):
     """
@@ -194,7 +198,8 @@ class PDEntryIO(object):
         elements = set()
         map(elements.update, [entry.composition.elements for entry in entries])
         elements = sorted(list(elements), key=lambda a: a.X)
-        writer = csv.writer(open(filename, 'wb'), delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
+        writer = csv.writer(open(filename, 'wb'), delimiter=',',
+                            quotechar='"', quoting=csv.QUOTE_MINIMAL)
         writer.writerow(['Name'] + elements + ['Energy'])
         for entry in entries:
             row = [entry.name if not latexify_names else re.sub(r"([0-9]+)", r"_{\1}", entry.name)]
@@ -214,7 +219,8 @@ class PDEntryIO(object):
             List of PDEntries
         """
         import csv
-        reader = csv.reader(open(filename, 'rb'), delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
+        reader = csv.reader(open(filename, 'rb'), delimiter=',',
+                            quotechar='"', quoting=csv.QUOTE_MINIMAL)
         entries = list()
         header_read = False
         for row in reader:
@@ -235,23 +241,25 @@ class PDEntryIO(object):
 
 class TransformedPDEntry(PDEntry):
     """
-    Beta object for transforming a PDEntry to a different composition coordinate
-    space. Experimental - may be removed in future releases.
+    This class repesents a TransformedPDEntry, which allows for a PDEntry to be
+    transformed to a different composition coordinate space. It is used in the
+    construction of phase diagrams that do not have elements as the terminal
+    compositions.
     """
 
-    def __init__(self, comp, energy, original_entry):
+    def __init__(self, comp, original_entry):
         """
         Args:
             comp:
-                Composition as a pymatgen.core.structure.Composition
+                Transformed composition as a pymatgen.core.structure.Composition
             energy:
                 Energy for composition.
             original_entry:
                 Original entry that this entry arose from.
         """
-        super(TransformedPDEntry, self).__init__(comp, energy)
+        PDEntry.__init__(self, comp, original_entry.energy)
         self._original_entry = original_entry
-        self._name = self._original_entry.composition.reduced_formula
+        self.name = original_entry.name
 
     @property
     def original_entry(self):
@@ -259,3 +267,33 @@ class TransformedPDEntry(PDEntry):
         Original PDEntry object.
         '''
         return self._original_entry
+
+    def __getattr__(self, a):
+        """
+        Delegate attribute to original entry if available.
+        """
+        if hasattr(self._original_entry, a):
+            return getattr(self._original_entry, a)
+        raise AttributeError(a)
+
+    def __repr__(self):
+        return "TransformedPDEntry {} with original composition {}, energy = {:.4f}".format(self.composition,
+                self.original_entry.composition,
+                self.original_entry.energy)
+
+    def __str__(self):
+        return self.__repr__()
+
+    @property
+    def to_dict(self):
+        d = {}
+        d['module'] = self.__class__.__module__
+        d['class'] = self.__class__.__name__
+        d['entry'] = self._original_entry.to_dict
+        d['composition'] = self.composition
+        return d
+
+    @staticmethod
+    def from_dict(d):
+        entry = PMGJSONDecoder().process_decoded(d['entry'])
+        return TransformedPDEntry(d['composition'], entry)
