@@ -6,18 +6,22 @@ This module provides classes to create phase diagrams.
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
-__version__ = "1.1"
+__version__ = "2.0"
 __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyue@mit.edu"
 __status__ = "Production"
-__date__ = "Sep 23, 2011"
+__date__ = "Jul 11, 2012"
 
 import numpy as np
+import collections
 import logging
 
 from pymatgen.core.structure import Composition
-from pymatgen.phasediagram.entries import GrandPotPDEntry
+from pymatgen.phasediagram.entries import GrandPotPDEntry, TransformedPDEntry
 from pymatgen.util.coord_utils import get_convex_hull
+from pymatgen.core.periodic_table import DummySpecie
+from pymatgen.analysis.reaction_calculator import Reaction, ReactionError
+
 
 logger = logging.getLogger(__name__)
 
@@ -369,3 +373,71 @@ class GrandPotentialPhaseDiagram(PhaseDiagram):
         return "\n".join(output)
 
 
+
+class CompoundPhaseDiagram(PhaseDiagram):
+    """
+    Generates phase diagrams from compounds as terminations instead of elements.
+    """
+
+    def __init__(self, entries, terminal_compositions,
+                 use_external_qhull=False):
+        """
+        Args:
+            entries:
+                Sequence of input entries. For example, if you want a Li2O-P2O5
+                phase diagram, you might have all Li-P-O entries as an input.
+            terminal_compositions:
+                Terminal compositions of phase space. In the Li2O-P2O5 example,
+                these will be the Li2O and P2O5 compositions.
+            use_external_qhull:
+                Similar to PhaseDiagram, set to True if you wish to use external
+                qhull command.
+        """
+        self.original_entries = entries
+        self.terminal_compositions = terminal_compositions
+        (pentries, species_mapping) = self.transform_entries(entries, terminal_compositions)
+        PhaseDiagram.__init__(self, pentries, elements=species_mapping.values(),
+                              use_external_qhull=use_external_qhull)
+
+    def transform_entries(self, entries, terminal_compositions):
+        """
+        Method to transform all entries to the composition coordinate in the
+        terminal compositions. If the entry does not fall within the space
+        defined by the terminal compositions, they are excluded. For example,
+        Li3PO4 is mapped into a Li2O:1.5, P2O5:0.5 composition. The terminal
+        compositions are represented by DummySpecies.
+        
+        Args:
+            entries:
+                Sequence of all input entries
+            terminal_compositions:
+                Terminal compositions of phase space.
+        
+        Returns:
+            Sequence of TransformedPDEntries falling within the phase space.
+        """
+        new_entries = []
+        #Map terminal compositions to unique dummy species.
+        sp_mapping = collections.OrderedDict()
+        for i, comp in enumerate(terminal_compositions):
+            sp_mapping[comp] = DummySpecie('X' + chr(102 + i))
+
+        for entry in entries:
+            try:
+                rxn = Reaction(terminal_compositions, [entry.composition])
+                rxn.normalize_to(entry.composition)
+                #We only allow reactions that have positive amounts of reactants.
+                if all([rxn.get_coeff(comp) <= 1e-5 for comp in terminal_compositions]):
+                    newcomp = {sp_mapping[comp]:-rxn.get_coeff(comp) \
+                               for comp in terminal_compositions}
+                    newcomp = {k: v for k, v in newcomp.items() if v > 1e-5}
+                    transformed_entry = TransformedPDEntry(Composition(newcomp),
+                                                           entry)
+                    new_entries.append(transformed_entry)
+            except ReactionError as ex:
+                #If the reaction can't be balanced, the entry does not fall
+                #into the phase space. We ignore them.
+                pass
+        return (new_entries, sp_mapping)
+
+
