@@ -6,11 +6,11 @@ This module provides classes for plotting PhaseDiagram objects.
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
-__version__ = "1.0"
+__version__ = "1.1"
 __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyue@mit.edu"
 __status__ = "Production"
-__date__ = "Sep 23, 2011"
+__date__ = "Jun 15, 2012"
 
 import math
 import numpy as np
@@ -146,6 +146,8 @@ class PDPlotter(object):
             plt.xlim((-0.1, 1.1))
             plt.ylim((miny - ybuffer, ybuffer))
             center = (0.5, miny / 2)
+            plt.xlabel("Fraction")
+            plt.ylabel("Formation energy from end members (eV)")
 
         for coords in sorted(labels.keys(), key=lambda x:-x[1]):
             entry = labels[coords]
@@ -185,7 +187,8 @@ class PDPlotter(object):
                              verticalalignment=valign,
                              fontproperties=font)
         F = plt.gcf()
-        F.set_size_inches((8, 6.4))
+        F.set_size_inches((8, 6))
+        plt.subplots_adjust(left=0.09, right=0.98, top=0.98, bottom=0.07)
         return plt
 
     def _get_3d_plot(self):
