@@ -19,7 +19,8 @@ import glob
 import numpy as np
 
 from pymatgen.core.operations import SymmOp
-from pymatgen.core.structure import PeriodicSite
+from pymatgen.core.sites import PeriodicSite
+
 
 class Spacegroup(object):
     """
@@ -64,8 +65,7 @@ class Spacegroup(object):
         """
         def in_sites(site):
             for test_site in sites1:
-                if test_site.species_and_occu == site.species_and_occu and\
-                            test_site.is_periodic_image(site, symprec):
+                if test_site.is_periodic_image(site, symprec, False):
                     return True
             return False
         for op in self._symmops:
