@@ -8,13 +8,14 @@ from __future__ import division
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
-__version__ = "0.1"
+__version__ = "1.0"
 __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyue@mit.edu"
 __date__ = "Nov 27, 2011"
 
 import numpy as np
 import warnings
+import math
 
 from pymatgen.command_line.qhull_caller import qconvex
 
@@ -94,3 +95,18 @@ def get_convex_hull(coords, use_external_qhull=False):
                           "Ignoring use_external_qhull = False and "
                           "attempting command-line qhull.")
     return qconvex(coords)
+
+
+def coords_to_unit_cell(coords):
+    """
+    Map a set of fractional coordinates into the unit cell, i.e. 
+    0 <= a < 1.
+    
+    Args:
+        coords:
+            A sequence of fractional coords.
+    
+    Returns:
+        The coords mapped to within the unit cell.
+    """
+    return [i - math.floor(i) for i in coords]
