@@ -16,9 +16,34 @@ import gzip
 import bz2
 import re
 import numpy
+import os
 
 
 def file_open_zip_aware(filename, *args, **kwargs):
+    """
+    .. deprecated:: 2.1.0
+        This function has been renamed to the much shorter :func:`zopen`. It
+        will be removed in future versions.
+        
+    This wrapper wraps around the bz2, gzip and standard python's open function 
+    to deal intelligently with bzipped, gzipped or standard text files.
+    
+    Args:
+        filename:
+            filename 
+        args:
+            Standard args for python open(..). E.g., 'r' for read, 'w' for
+            write.
+        kwargs:
+            Standard kwargs for python open(..).
+            
+    Returns:
+        File handler
+    """
+    return zopen(filename, *args, **kwargs)
+
+
+def zopen(filename, *args, **kwargs):
     """
     This wrapper wraps around the bz2, gzip and standard python's open function 
     to deal intelligently with bzipped, gzipped or standard text files.
@@ -35,9 +60,10 @@ def file_open_zip_aware(filename, *args, **kwargs):
     Returns:
         File handler
     """
-    if filename.split(".")[-1].upper() == "BZ2":
+    file_ext = filename.split(".")[-1].upper()
+    if file_ext == "BZ2":
         return bz2.BZ2File(filename, *args, **kwargs)
-    elif filename.split(".")[-1].upper() == "GZ" or filename.split(".")[-1] == "z":
+    elif file_ext in ("GZ", "Z"):
         return gzip.GzipFile(filename, *args, **kwargs)
     else:
         return open(filename, *args, **kwargs)
@@ -98,7 +124,7 @@ def micro_pyawk(filename, search, results=None, debug=None, postdebug=None):
         if isinstance(entry[0], str):
             entry[0] = re.compile(entry[0])
 
-    reader = file_open_zip_aware(filename)
+    reader = zopen(filename)
     for line in reader:
         for i in range(len(search)):
             match = search[i][0].search(line)
@@ -148,3 +174,23 @@ def clean_json(input_json, strict=False):
                 return 'None'
             else:
                 return clean_json(input_json.to_dict, strict=strict)
+
+
+def which(program):
+    """
+    Returns full path to a executable.
+    """
+    def is_exe(fpath):
+        return os.path.isfile(fpath) and os.access(fpath, os.X_OK)
+
+    fpath, fname = os.path.split(program)
+    if fpath:
+        if is_exe(program):
+            return program
+    else:
+        for path in os.environ["PATH"].split(os.pathsep):
+            exe_file = os.path.join(path, program)
+            if is_exe(exe_file):
+                return exe_file
+
+    return None
