@@ -25,6 +25,7 @@ import vtk
 from pymatgen.util.coord_utils import in_coord_list
 from pymatgen.core.periodic_table import Specie
 from pymatgen.core.structure_modifier import SupercellMaker
+from pymatgen.core.structure import Structure
 
 
 class StructureVis(object):
@@ -71,6 +72,7 @@ class StructureVis(object):
             [ : Decrease poly_radii_tol_factor by 0.05
             ] : Increase poly_radii_tol_factor by 0.05
             r : Reset camera direction
+            o : Orthogonalize structure
             Up/Down : Rotate view along Up direction by 90 clock/anticlockwise
             Left/right : Rotate view along camera direction by 90 clock/anticlockwise
         """
@@ -90,12 +92,12 @@ class StructureVis(object):
             self.el_color_mapping = element_color_mapping
         else:
             module_dir = os.path.dirname(os.path.abspath(__file__))
-            self._config = ConfigParser.SafeConfigParser()
-            self._config.optionxform = str
-            self._config.readfp(open(os.path.join(module_dir, "ElementColorSchemes.cfg")))
+            config = ConfigParser.SafeConfigParser()
+            config.optionxform = str
+            config.readfp(open(os.path.join(module_dir, "ElementColorSchemes.cfg")))
 
             self.el_color_mapping = {}
-            for (el, color) in self._config.items('VESTA'):
+            for (el, color) in config.items('VESTA'):
                 self.el_color_mapping[el] = [int(i) for i in color.split(",")]
         self.show_unit_cell = show_unit_cell
         self.show_bonds = show_bonds
@@ -181,6 +183,11 @@ class StructureVis(object):
 
         self.ren_win.Render()
 
+    def orthongonalize_structure(self):
+        if self.structure != None:
+            self.set_structure(self.structure.copy(sanitize=True))
+        self.ren_win.Render()
+
     def display_help(self):
         """
         Display the help for various keyboard shortcuts.
@@ -193,7 +200,8 @@ class StructureVis(object):
         helptxt.append('[/]: Decrease or increase poly_radii_tol_factor by 0.05. Value = ' + str(self.poly_radii_tol_factor))
         helptxt.append('Up/Down: Rotate view along Up direction by 90 clockwise/anticlockwise')
         helptxt.append('Left/right: Rotate view along camera direction by 90 clockwise/anticlockwise')
-        helptxt.append('i: Save view to image.png')
+        helptxt.append('s: Save view to image.png')
+        helptxt.append('o: Orthogonalize structure')
         self.helptxt_mapper.SetInput("\n".join(helptxt))
         self.helptxt_actor.SetPosition(10, 10)
         self.helptxt_actor.VisibilityOn()
@@ -212,6 +220,8 @@ class StructureVis(object):
         self.ren.RemoveAllViewProps()
         m = SupercellMaker(structure, self.supercell)
         s = m.modified_structure
+        all_sites = [site.to_unit_cell for site in s]
+        s = Structure.from_sites(all_sites)
 
         inc_coords = []
         for site in s:
@@ -321,6 +331,7 @@ class StructureVis(object):
         radius = 0
         total_occu = 0
 
+
         for specie, occu in site.species_and_occu.items():
             radius += occu * (specie.ionic_radius if isinstance(specie, Specie) and specie.ionic_radius else specie.average_ionic_radius)
             total_occu += occu
@@ -614,6 +625,9 @@ class StructureInteractorStyle(vtk.vtkInteractorStyleTrackballCamera):
             parent.rotate_view(0, -90)
         elif sym == "Right":
             parent.rotate_view(0, 90)
+        elif sym == "o":
+            parent.orthongonalize_structure()
+            parent.redraw()
 
         self.OnKeyPress()
 
